def reset_sigpipe_handling():
    '''Restore the default `SIGPIPE` handler on supporting platforms.
    Python's `signal` library traps the SIGPIPE signal and translates it
    into an IOError exception, forcing the caller to handle it explicitly.

    Simpler applications that would rather silently die can revert to the
    default handler. See https://stackoverflow.com/a/30091579/1026 for details.
    '''
    try:
        from signal import signal, SIGPIPE, SIG_DFL
        signal(SIGPIPE, SIG_DFL)
    except ImportError:  # If SIGPIPE is not available (win32),
        pass             # we don't have to do anything to ignore it.



import importlib.util

def to_dict(**kwargs) -> dict:
    ''' Returns a dictionary from kwargs '''
    return kwargs

def module_from_file(module_name: str, file_path: str):
    ''' Returns a hookable python module from a given file path '''
    spec = importlib.util.spec_from_file_location(module_name, file_path)
    module = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(module)
    return module



from setuptools import find_packages, setup

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='wora',
    version='0.1.7',
    license='GPLv3',
    author='Joseph Diza',
    author_email='josephm.diza@gmail.com',
    description='Write once, run anywhere, a python library with general purpose utilities.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/jmdaemon/wora',
    project_urls={ 'Bug Tracker': 'https://github.com/jmdaemon/wora/issues', },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: OS Independent',
    ],
    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    python_requires='>=3.6',
    py_modules=['wora.file', 'wora.dynmod'],
    install_requires=['toml'],
    include_package_data=True,
    zip_safe=False,
    test_suite='tests',
)



import pathlib
import toml

def to_path(fp: str) -> pathlib.Path:
    ''' Convert str to Path '''
    if isinstance(fp, pathlib.Path):
        return fp
    elif isinstance(fp, str):
        return pathlib.Path(fp)

def read_file(fname: str) -> str:
    ''' Reads a file into a string '''
    file = open(fname, 'r')
    res = file.read()
    file.close()
    return res

def write_file(fname: str, content: str):
    ''' Write a string to a file '''
    file = open(fname, 'w')
    file.write(content)
    file.close()

def mkdir(file):
    ''' Make a directory from a str or Path '''
    if isinstance(file, str):
        pathlib.Path(file).mkdir(parents=True, exist_ok=True)
    elif isinstance(file, pathlib.Path):
        file.mkdir(parents=True, exist_ok=True)

def load_toml_config(configfp: str) -> dict:
    ''' Reads the toml config file into a dictionary '''
    result = dict
    if (to_path(configfp).exists()):
        result = toml.loads(read_file(configfp))
    return result
